@@ -6,12 +6,7 @@ package PostScript::TextBlock;
 use strict;
 use PostScript::Metrics;
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw();
+use vars qw($VERSION);
 $VERSION = '0.04';
 
 # The valid text block attribute names
